@@ -12,6 +12,8 @@ from enum import Enum
 
 
 class SafetyKeyMixin:
+    pydantic_reserved_properties = ("schema",)
+
     @property
     def key(self):
         return self._safe_key()
@@ -20,58 +22,70 @@ class SafetyKeyMixin:
         if self.safety_key:
             return self.safety_key
 
-        if self.orig_key.isidentifier() and not keyword.iskeyword(self.orig_key):
+        if all(
+            (
+                self.orig_key.isidentifier(),
+                not keyword.iskeyword(self.orig_key),
+                self.orig_key not in self.pydantic_reserved_properties,
+            )
+        ):
             return self.orig_key
 
         key = self.orig_key
 
         if not key.isidentifier():
-            key = re.sub('[-.]', '_', key)
+            key = re.sub("[-.]", "_", key)
             # stolen from https://stackoverflow.com/a/3303361
-            key = re.sub('[^0-9a-zA-Z_]', '', key)
-            key = re.sub('^[^a-zA-Z_]+', '', key)
+            key = re.sub("[^0-9a-zA-Z_]", "", key)
+            key = re.sub("^[^a-zA-Z_]+", "", key)
 
         if keyword.iskeyword(key):
             key += "_"
 
+        if key in self.pydantic_reserved_properties:
+            key += "_"
+
         self.safety_key = key
         return self.safety_key
 
 
 class HttpMethod(Enum):
-    get = 'get'
-    put = 'put'
-    post = 'post'
-    delete = 'delete'
-    options = 'options'
-    head = 'head'
-    patch = 'patch'
-    trace = 'trace'
+    get = "get"
+    put = "put"
+    post = "post"
+    delete = "delete"
+    options = "options"
+    head = "head"
+    patch = "patch"
+    trace = "trace"
 
 
 class ParameterLocation(Enum):
-    query = 'query'
-    header = 'header'
-    path = 'path'
-    cookie = 'cookie'
+    query = "query"
+    header = "header"
+    path = "path"
+    cookie = "cookie"
 
 
 class Format(Enum):
-    int32 = 'int32'
-    int64 = 'int64'
-    float = 'float'
-    double = 'double'
-    date = 'date'
-    byte = 'byte'
-    binary = 'binary'
-    datetime = 'date-time'
-    password = 'password'
-    uuid = 'uuid'
-    uri = 'uri'
+    int32 = "int32"
+    int64 = "int64"
+    float = "float"
+    double = "double"
+    date = "date"
+    byte = "byte"
+    binary = "binary"
+    datetime = "date-time"
+    password = "password"
+    uuid = "uuid"
+    uri = "uri"
+    hostname = "hostname"
+    ipv4 = "ipv4"
+    ipv6 = "ipv6"
 
     @classmethod
     def _missing_(cls, value):
-        value = re.sub('[_-]*', '', value)
+        value = re.sub("[_-]*", "", value)
         for member in cls:
             if member.name.lower() == value:
                 return member
@@ -114,23 +128,30 @@ class InfoObject:
 
 
 class Type(Enum):
-    string = 'string'
-    number = 'number'
-    integer = 'integer'
-    boolean = 'boolean'
-    array = 'array'
-    object = 'object'
-    null = 'null'
+    string = "string"
+    number = "number"
+    integer = "integer"
+    boolean = "boolean"
+    array = "array"
+    object = "object"
+    null = "null"
 
-    # TODO: refactor
-    any_of = 'any_of'
+    @property
+    def is_primitive(self) -> bool:
+        return self in (
+            Type.string,
+            Type.number,
+            Type.integer,
+            Type.boolean,
+            Type.null,
+        )
 
 
 @dataclass
 class SchemaProperty(SafetyKeyMixin):
     orig_key: str
     safety_key: str | None
-    schema: 'SchemaObject'
+    schema: "SchemaObject"
 
 
 @dataclass
@@ -141,34 +162,61 @@ class SchemaObject:
 
     id: str
     title: str | None
-    required: list[str] | None
     enum: list[str] | None
     type: Type
     format: Format | None
-    items: 'SchemaObject' | list['SchemaObject'] | None
+    items: "SchemaObject" | list["SchemaObject"] | None
     properties: list[SchemaProperty]
     description: str | None = None
     additional_roperties: bool = False
-    all_of: list['SchemaObject'] = field(default_factory=list)
+    required: list[str] = field(default_factory=list)
+    all_of: list["SchemaObject"] = field(default_factory=list)
+    any_of: list["SchemaObject"] = field(default_factory=list)
+    discriminator: Discriminator | None = None
 
     # Технические поля
     discriminator_base_class_schema: DiscriminatorBaseClassSchema | None = None
     is_fake: bool = False
+    is_inline: bool = False
 
     @property
     def required_properties(self) -> list[SchemaProperty]:
-        if self.required is None:
+        if not self.required:
             return []
 
         return [p for p in self.properties if p.orig_key in self.required]
 
     @property
     def optional_properties(self) -> list[SchemaProperty]:
-        if self.required is None:
+        if not self.required:
             return self.properties
 
         return [p for p in self.properties if p.orig_key not in self.required]
 
+    @property
+    def inline_allof_models(self) -> list[SchemaObject]:
+        return [item for item in self.all_of if item.is_inline]
+
+    @property
+    def named_allof_models(self) -> list[SchemaObject]:
+        return [item for item in self.all_of if not item.is_inline]
+
+    @property
+    def is_empty_object(self) -> bool:
+        return all(
+            (
+                self.type is Type.object,
+                not self.is_fake,
+                not self.enum,
+                not self.items,
+                not self.properties,
+                not self.required,
+                not self.all_of,
+                not self.any_of,
+                not self.discriminator,
+            )
+        )
+
 
 @dataclass
 class ParameterObject(SafetyKeyMixin):
@@ -230,10 +278,10 @@ class OperationObject:
     @property
     def fn_name(self) -> str | None:
         if self.operation_id is not None:
-            return self.operation_id.replace('-', '_')
+            return self.operation_id.replace("-", "_")
 
-        name = self.path_str.removeprefix('/').replace('-', '_').replace('/', '_').replace('{', '').replace('}', '')
-        name = self.method.value + '_' + name
+        name = self.path_str.removeprefix("/").replace("-", "_").replace("/", "_").replace("{", "").replace("}", "")
+        name = self.method.value + "_" + name
         name = name.lower()
         return name
 
@@ -310,7 +358,7 @@ class Document:
 
     @property
     def sorted_schemas(self) -> list[SchemaObject]:
-        keys = [key for key, schema in self.schemas.items() if schema.enum is None]
+        keys = [key for key, schema in self.schemas.items() if schema.enum is None and not schema.type.is_primitive]
         return self._build_sorted_schemas(keys, exclude_enums=True)
 
     @property
@@ -323,3 +371,9 @@ class Document:
 class DiscriminatorBaseClassSchema:
     name: str
     attr: str
+
+
+@dataclass
+class Discriminator:
+    property_name: str
+    mapping: dict[str, SchemaObject]
