@@ -35,19 +35,19 @@ def init_package(
     sources_path.mkdir(parents=True, exist_ok=True)
     _create_init_file(sources_path, package_name)
 
-    return InitPackageResponse(client_output_path=str(sources_path.joinpath(f'{package_name}.py')))
+    return InitPackageResponse(client_output_path=str(sources_path.joinpath(f"{package_name}.py")))
 
 
 def _create_pyproject_file(output_dir: Path, package_name: str, version: str, authors: str | None = None) -> None:
     env = Environment(
         loader=FileSystemLoader(settings.HTTP_PACKAGE_TEMPLATES_DIR_PATH),
-        extensions=['jinja2.ext.loopcontrols'],
+        extensions=["jinja2.ext.loopcontrols"],
     )
-    template = env.get_template('pyproject-toml.j2')
+    template = env.get_template("pyproject-toml.j2")
 
-    pyproject_path = output_dir.joinpath('pyproject.toml')
+    pyproject_path = output_dir.joinpath("pyproject.toml")
 
-    with open(pyproject_path, 'w') as pyproject_file:
+    with open(pyproject_path, "w") as pyproject_file:
         pyproject_file.write(
             template.render(
                 name=package_name,
@@ -60,13 +60,13 @@ def _create_pyproject_file(output_dir: Path, package_name: str, version: str, au
 def _create_init_file(output_dir: Path, module_name: str) -> None:
     env = Environment(
         loader=FileSystemLoader(settings.HTTP_PACKAGE_TEMPLATES_DIR_PATH),
-        extensions=['jinja2.ext.loopcontrols'],
+        extensions=["jinja2.ext.loopcontrols"],
     )
-    template = env.get_template('init-py.j2')
+    template = env.get_template("init-py.j2")
 
-    init_path = output_dir.joinpath('__init__.py')
+    init_path = output_dir.joinpath("__init__.py")
 
-    with open(init_path, 'w') as init_file:
+    with open(init_path, "w") as init_file:
         init_file.write(
             template.render(
                 module_name=module_name,
