@@ -1,19 +1,14 @@
-import logging
 import re
 from collections import defaultdict
 from typing import Any
 
+from pythogen import console
+from pythogen import exceptions
 from pythogen import models
 from pythogen.parsers.inline_schemas_aggregator import InlineSchemasAggregator
 from pythogen.parsers.references import RefResolver
 
 
-logger = logging.getLogger(__name__)
-
-
-PRIMITIVE_TYPES = ('string', 'number', 'integer', 'boolean', 'null')
-
-
 class SchemaParser:
     """Парсер схемы
 
@@ -56,10 +51,10 @@ class SchemaParser:
         self._schemas: dict[str, models.SchemaObject] = {}
 
     def parse_collection(self) -> dict[str, models.SchemaObject]:
-        schemas_data = self._openapi_data.get('components', {}).get('schemas', {})
+        schemas_data = self._openapi_data.get("components", {}).get("schemas", {})
         for schema_id, schema_data in schemas_data.items():
-            if schema_data.get('$ref', None):
-                resolved_ref = self._ref_resolver.resolve(schema_data['$ref'])
+            if schema_data.get("$ref", None):
+                resolved_ref = self._ref_resolver.resolve(schema_data["$ref"])
                 schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data)
             else:
                 schema = self.parse_item(schema_id, schema_data)
@@ -70,7 +65,7 @@ class SchemaParser:
         return self._schemas
 
     def parse_item(
-        self, schema_id: str, schema_data: dict[str, Any], from_depth_level: bool = False
+        self, schema_id: str, schema_data: dict[str, Any], from_depth_level: bool = False, is_inline: bool = False
     ) -> models.SchemaObject:
         """Спарсить схему из OpenAPI-спеки
 
@@ -89,6 +84,7 @@ class SchemaParser:
 
         schema_type = self._parse_type(schema_data)
         all_of = self._parse_all_of(schema_id, schema_data)
+        any_of = self._parse_any_of(schema_id, schema_data)
 
         self._processiong_parsed_schema_id_count[schema_id] += 1
         if self._processiong_parsed_schema_id_count[schema_id] > 1 and from_depth_level:
@@ -104,9 +100,9 @@ class SchemaParser:
             """
             return models.SchemaObject(
                 id=schema_id,
-                title=schema_data.get('title'),
-                required=schema_data.get('required'),
-                enum=schema_data.get('enum'),
+                title=schema_data.get("title"),
+                required=schema_data.get("required", []),
+                enum=schema_data.get("enum"),
                 type=schema_type,
                 format=self._parse_format(schema_data),
                 items=[],
@@ -114,6 +110,9 @@ class SchemaParser:
                 description=self._get_description(schema_data),
                 is_fake=True,
                 all_of=all_of,
+                any_of=any_of,
+                is_inline=is_inline,
+                discriminator=self._parse_discriminator(schema_data),
             )
 
         discr_schema = self._get_discriminator_base_class_schema(schema_data)
@@ -122,32 +121,52 @@ class SchemaParser:
 
         return models.SchemaObject(
             id=schema_id,
-            title=schema_data.get('title'),
-            required=schema_data.get('required'),
-            enum=schema_data.get('enum'),
+            title=schema_data.get("title"),
+            required=schema_data.get("required", []),
+            enum=schema_data.get("enum"),
             type=schema_type,
             format=self._parse_format(schema_data),
             items=self._parse_items(schema_id, schema_data),
             properties=self._parse_properties(schema_type, schema_data),
             description=self._get_description(schema_data),
             all_of=all_of,
+            any_of=any_of,
+            is_inline=is_inline,
+            discriminator=self._parse_discriminator(schema_data),
         )
 
     def _parse_all_of(self, parent_id: str, parent_data: dict[str, Any]) -> list[models.SchemaObject]:
         result: list[models.SchemaObject] = []
-        for all_of_item_num, all_of_item in enumerate(parent_data.get("allOf", [])):
-            if ref := all_of_item.get('$ref'):
+        for i, all_of_item in enumerate(parent_data.get("allOf", [])):
+            if ref := all_of_item.get("$ref"):
                 resolved_ref = self._ref_resolver.resolve(ref)
-                all_of_item_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data)
+                all_of_item_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
                 result.append(all_of_item_schema)
             else:
-                all_of_item_schema_id = f"{parent_id}_item_{all_of_item_num}"
-                all_of_item_schema = self.parse_item(all_of_item_schema_id, all_of_item)
+                all_of_item_schema_id = f"{parent_id}_item_{i}"
+                all_of_item_schema = self.parse_item(
+                    all_of_item_schema_id, all_of_item, from_depth_level=True, is_inline=True
+                )
                 self._inline_schema_aggregator.add(all_of_item_schema_id, all_of_item_schema)
                 result.append(all_of_item_schema)
 
         return result
 
+    def _parse_any_of(self, parent_id: str, parent_data: dict[str, Any]) -> list[models.SchemaObject]:
+        result: list[models.SchemaObject] = []
+        for i, any_of_item in enumerate(parent_data.get("anyOf", [])):
+            if ref := any_of_item.get("$ref"):
+                resolved_ref = self._ref_resolver.resolve(ref)
+                any_of_item_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
+                result.append(any_of_item_schema)
+            else:
+                any_of_item_schema_id = f"{parent_id}_item_{i}"
+                any_of_item_schema = self.parse_item(any_of_item_schema_id, any_of_item, from_depth_level=True)
+                self._inline_schema_aggregator.add(any_of_item_schema_id, any_of_item_schema)
+                result.append(any_of_item_schema)
+
+        return result
+
     def _parse_type(self, data: dict[str, Any]) -> models.Type:
         if data == {}:
             # Парсинг пустой схемы
@@ -155,27 +174,27 @@ class SchemaParser:
             #   schema:
             #     {}
             data_type = models.Type.object
-        elif 'allOf' in data:
+        elif "allOf" in data:
             data_type = models.Type.object
-        elif 'anyOf' in data:
-            data_type = models.Type.any_of
-        elif 'type' not in data:
+        elif "anyOf" in data:
+            data_type = models.Type.object
+        elif "type" not in data:
             data_type = models.Type.object
         else:
-            raw_data_type: str | None = data.get('type')
+            raw_data_type: str | None = data.get("type")
             try:
                 data_type = models.Type(raw_data_type)
-            except ValueError:
-                raise Exception(f'Unable to parse schema "{id}", unknown type "{raw_data_type}" on "{data}"')
+            except ValueError as exc:
+                raise Exception(f'Unable to parse schema, unknown type "{raw_data_type}" on "{data}"') from exc
         return data_type
 
     def _parse_format(self, data: dict[str, Any]) -> models.Format | None:
-        data_format = data.get('format')
+        data_format = data.get("format")
         if data_format:
             try:
                 return models.Format(data_format)
-            except Exception:
-                raise Exception(f'Unable to parse schema "{id}", unknown format "{data_format}"')
+            except Exception as exc:
+                raise Exception(f'Unable to parse schema, unknown format "{data_format}"') from exc
         return None
 
     def _get_description(self, data: dict[str, Any]) -> str | None:
@@ -186,6 +205,42 @@ class SchemaParser:
             description = description.replace('"', '\\"')
         return description
 
+    def _parse_discriminator(self, data: dict[str, Any]) -> models.Discriminator | None:
+        raw_discriminator: dict[str, Any] | None = data.get("discriminator")
+
+        if not raw_discriminator:
+            return None
+
+        property_name: str | None = raw_discriminator.get("propertyName")
+        if not property_name:
+            console.print_error(
+                title="Failed to generate a client",
+                msg='The discriminator must contain the "propertyName" field.',
+                invalid_data=data,
+            )
+            raise exceptions.Exit()
+
+        raw_mapping: dict[str, Any] | None = raw_discriminator.get("mapping")
+        if not raw_mapping:
+            console.print_error(
+                title="Failed to generate a client",
+                msg='The discriminator must contain the "mapping" field.',
+                invalid_data=data,
+            )
+            raise exceptions.Exit()
+
+        mapping: dict[str, models.SchemaObject] = {}
+        for discriminator_value, ref in raw_mapping.items():
+            resolved_ref = self._ref_resolver.resolve(ref)
+            schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
+            mapping[discriminator_value] = schema
+
+        return models.Discriminator(
+            property_name=property_name,
+            mapping=mapping,
+        )
+
+    # TODO: remove
     def _get_discriminator_base_class_schema(
         self,
         data: dict[str, Any],
@@ -205,52 +260,52 @@ class SchemaParser:
         schema_type: models.Type,
         data: dict[str, Any],
     ) -> list[models.SchemaProperty]:
-        data_format = data.get('format')
+        data_format = data.get("format")
         if data_format:
             try:
                 data_format = models.Format(data_format)
-            except Exception:
-                raise Exception(f'Unable to parse schema "{id}", unknown format "{data_format}"')
+            except Exception as exc:
+                raise Exception(f'Unable to parse schema "{id}", unknown format "{data_format}"') from exc
 
         properties = []
 
-        properties_map = data.get('properties')
+        properties_map = data.get("properties")
         if properties_map:
             for key, property_schema_data in properties_map.items():
-                if property_schema_data.get('$ref', None):
-                    resolved_ref = self._ref_resolver.resolve(property_schema_data['$ref'])
+                if property_schema_data.get("$ref", None):
+                    resolved_ref = self._ref_resolver.resolve(property_schema_data["$ref"])
                     property_schema_data = resolved_ref.ref_data
                     property_schema_id = resolved_ref.ref_id
                     schema = self.parse_item(property_schema_id, property_schema_data, from_depth_level=True)
                 else:
                     if (
-                        property_schema_data.get('type') == models.Type.object.value
-                        and 'properties' in property_schema_data
+                        property_schema_data.get("type") == models.Type.object.value
+                        and "properties" in property_schema_data
                     ):
                         # extract inline object definition to schema
                         property_schema_id = key + "_obj"
                         schema = self.parse_item(property_schema_id, property_schema_data)
                         self._inline_schema_aggregator.add(property_schema_id, schema)
-                    elif 'allOf' in property_schema_data:
+                    elif "allOf" in property_schema_data:
                         property_schema_id = key + "_ref_obj"
                         schema = self.parse_item(property_schema_id, property_schema_data)
                         self._inline_schema_aggregator.add(property_schema_id, schema)
-                    elif property_schema_data.get('type') == models.Type.array.value:
+                    elif property_schema_data.get("type") == models.Type.array.value:
                         # specify inline array name
                         property_schema_id = key + "_list"
                         schema = self.parse_item(property_schema_id, property_schema_data)
-                    elif 'anyOf' in property_schema_data:
+                    elif "anyOf" in property_schema_data:
                         # extract inline object definition to schema
                         property_schema_id = key + "_obj"
                         schema = self.parse_item(property_schema_id, property_schema_data)
                         self._inline_schema_aggregator.add(property_schema_id, schema)
                     else:
-                        property_schema_id = f'<inline+{models.SchemaObject.__name__}>'
+                        property_schema_id = f"<inline+{models.SchemaObject.__name__}>"
                         schema = self.parse_item(property_schema_id, property_schema_data)
 
                 description = property_schema_data.get("description", "")
                 match = re.search(r"(__safety_key__)\((?P<safety_key>.+)\)", description)
-                safety_key = match['safety_key'] if match else None
+                safety_key = match["safety_key"] if match else None
 
                 properties.append(
                     models.SchemaProperty(
@@ -263,34 +318,34 @@ class SchemaParser:
             if schema_type == models.Type.string and not data_format:
                 properties.append(
                     models.SchemaProperty(
-                        orig_key='text',
+                        orig_key="text",
                         safety_key=None,
                         schema=models.SchemaObject(
-                            id='',
+                            id="",
                             type=models.Type.string,
                             enum=None,
                             properties=[],
                             title=None,
                             format=None,
                             items=None,
-                            required=None,
+                            required=[],
                         ),
                     )
                 )
             if schema_type == models.Type.string and data_format == models.Format.binary:
                 properties.append(
                     models.SchemaProperty(
-                        orig_key='content',
+                        orig_key="content",
                         safety_key=None,
                         schema=models.SchemaObject(
-                            id='',
+                            id="",
                             type=models.Type.string,
                             enum=None,
                             properties=[],
                             title=None,
                             format=models.Format.binary,
                             items=None,
-                            required=None,
+                            required=[],
                         ),
                     )
                 )
@@ -298,17 +353,17 @@ class SchemaParser:
             if schema_type == models.Type.integer:
                 properties.append(
                     models.SchemaProperty(
-                        orig_key='text',
+                        orig_key="text",
                         safety_key=None,
                         schema=models.SchemaObject(
-                            id='',
+                            id="",
                             type=models.Type.integer,
                             enum=None,
                             properties=[],
                             title=None,
                             format=None,
                             items=None,
-                            required=None,
+                            required=[],
                         ),
                     )
                 )
@@ -320,107 +375,24 @@ class SchemaParser:
         parent_schema_id: str,
         data: dict[str, Any],
     ) -> models.SchemaObject | list[models.SchemaObject] | None:
-        items_schema_data = data.get('items')
+        items_schema_data = data.get("items")
         if items_schema_data:
-            if items_schema_data.get('$ref', None):
-                resolved_ref = self._ref_resolver.resolve(items_schema_data['$ref'])
+            if items_schema_data.get("$ref", None):
+                resolved_ref = self._ref_resolver.resolve(items_schema_data["$ref"])
                 schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
                 return schema
-            elif items_schema_data.get('anyOf'):
-                items = []
-                for any_ref_item in items_schema_data['anyOf']:
-                    ref = any_ref_item.get('$ref', None)
-                    any_ref_any_type = any_ref_item.get('type')
-                    if ref:
-                        resolved_ref = self._ref_resolver.resolve(ref)
-                        ref_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
-                        items.append(ref_schema)
-                    elif any_ref_any_type in PRIMITIVE_TYPES:
-                        items.append(
-                            models.SchemaObject(
-                                id='',
-                                type=models.Type(any_ref_any_type),
-                                enum=None,
-                                properties=[],
-                                title=None,
-                                format=None,
-                                items=None,
-                                required=None,
-                            )
-                        )
-                    else:
-                        items_schema_id = f'<inline+{models.SchemaObject.__name__}>'
-                        schema = self.parse_item(items_schema_id, items_schema_data)
-                        self._inline_schema_aggregator.add(items_schema_id, schema)
-
-                return models.SchemaObject(
-                    id='',
-                    type=models.Type.any_of,
-                    enum=None,
-                    properties=[],
-                    title=None,
-                    format=None,
-                    items=items,
-                    required=None,
-                )
             else:
-                parent_raw_type = data.get('type')
-                if parent_raw_type == 'array':
-                    items_schema_id = f'{parent_schema_id}Item'
+                parent_raw_type = data.get("type")
+                if parent_raw_type == "array":
+                    items_schema_id = f"{parent_schema_id}Item"
                 else:
-                    items_schema_id = f'<inline+{models.SchemaObject.__name__}>'
+                    items_schema_id = f"<inline+{models.SchemaObject.__name__}>"
                 schema = self.parse_item(items_schema_id, items_schema_data)
-                if items_schema_data.get('type') not in PRIMITIVE_TYPES:
+                items_schema_data_type = items_schema_data.get("type")
+
+                if items_schema_data_type and not models.Type(items_schema_data_type).is_primitive:
                     self._inline_schema_aggregator.add(items_schema_id, schema)
+
                 return schema
 
-        if data.get('anyOf'):
-            items = []
-            for any_ref_item in data['anyOf']:
-                ref = any_ref_item.get('$ref', None)
-                any_ref_any_type = any_ref_item.get('type')
-                if ref:
-                    resolved_ref = self._ref_resolver.resolve(ref)
-                    ref_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
-                    items.append(ref_schema)
-                elif any_ref_any_type in PRIMITIVE_TYPES:
-                    items.append(
-                        models.SchemaObject(
-                            id='',
-                            type=models.Type(any_ref_any_type),
-                            enum=None,
-                            properties=[],
-                            title=None,
-                            format=None,
-                            items=None,
-                            required=None,
-                        )
-                    )
-                elif models.Type(any_ref_any_type) is models.Type.object:
-                    additional_roperties = any_ref_item.get('additionalProperties', False)
-                    if additional_roperties:
-                        item_schema_id = f'{parent_schema_id}Item'
-                        items.append(
-                            models.SchemaObject(
-                                id=item_schema_id,
-                                type=models.Type.object,
-                                enum=None,
-                                properties=[],
-                                title=None,
-                                format=None,
-                                items=None,
-                                required=None,
-                                additional_roperties=True,
-                            )
-                        )
-                elif models.Type(any_ref_any_type) is models.Type.array:
-                    schema_id = f'<inline+{models.SchemaObject.__name__}>'
-                    schema = self.parse_item(schema_id, any_ref_item)
-                    items.append(schema)
-                else:
-                    schema_id = f'<inline+{models.SchemaObject.__name__}>'
-                    schema = self.parse_item(schema_id, any_ref_item)  # type: ignore
-                    self._inline_schema_aggregator.add(schema_id, schema)
-            return items
-
         return None
